aboutsummaryrefslogtreecommitdiffstats
path: root/src/com/vaadin/event
diff options
context:
space:
mode:
authorMatti Tahvonen <matti.tahvonen@itmill.com>2010-03-24 16:25:51 +0000
committerMatti Tahvonen <matti.tahvonen@itmill.com>2010-03-24 16:25:51 +0000
commit68d907d504ed62963c08f903f19d5262ef62ab34 (patch)
tree3f83e844c1680172863c265dbba09238804b1f3e /src/com/vaadin/event
parentc8fbcdc7dc02d36ddbcd2cb8ab061d45db04e154 (diff)
downloadvaadin-framework-68d907d504ed62963c08f903f19d5262ef62ab34.tar.gz
vaadin-framework-68d907d504ed62963c08f903f19d5262ef62ab34.zip
renamed DropTargetDetails... to TargetDetails... Should be just as clear for developer, but looks better in the code examples.
svn changeset:12077/svn branch:6.3
Diffstat (limited to 'src/com/vaadin/event')
-rw-r--r--src/com/vaadin/event/dd/DragAndDropEvent.java8
-rw-r--r--src/com/vaadin/event/dd/DropTarget.java4
-rw-r--r--src/com/vaadin/event/dd/TargetDetails.java (renamed from src/com/vaadin/event/dd/DropTargetDetails.java)14
-rw-r--r--src/com/vaadin/event/dd/TargetDetailsImpl.java (renamed from src/com/vaadin/event/dd/DropTargetDetailsImpl.java)10
-rw-r--r--src/com/vaadin/event/dd/acceptcriteria/TargetDetailIs.java4
5 files changed, 20 insertions, 20 deletions
diff --git a/src/com/vaadin/event/dd/DragAndDropEvent.java b/src/com/vaadin/event/dd/DragAndDropEvent.java
index 01817200f9..721e000369 100644
--- a/src/com/vaadin/event/dd/DragAndDropEvent.java
+++ b/src/com/vaadin/event/dd/DragAndDropEvent.java
@@ -16,7 +16,7 @@ import com.vaadin.event.dd.acceptcriteria.AcceptCriterion;
* <p>
* DragAndDropEvent instances contains both the dragged data in
* {@link Transferable} (generated by {@link DragSource} and details about the
- * current drop event in {@link DropTargetDetails} (generated by
+ * current drop event in {@link TargetDetails} (generated by
* {@link DropTarget}.
*
* @since 6.3
@@ -24,10 +24,10 @@ import com.vaadin.event.dd.acceptcriteria.AcceptCriterion;
*/
public class DragAndDropEvent implements Serializable {
private Transferable transferable;
- private DropTargetDetails dropTargetDetails;
+ private TargetDetails dropTargetDetails;
public DragAndDropEvent(Transferable transferable,
- DropTargetDetails dropTargetDetails) {
+ TargetDetails dropTargetDetails) {
this.transferable = transferable;
this.dropTargetDetails = dropTargetDetails;
}
@@ -44,7 +44,7 @@ public class DragAndDropEvent implements Serializable {
* @return the DropTargetDetails containing drop target related details of
* drag and drop operation
*/
- public DropTargetDetails getDropTargetDetails() {
+ public TargetDetails getDropTargetDetails() {
return dropTargetDetails;
}
diff --git a/src/com/vaadin/event/dd/DropTarget.java b/src/com/vaadin/event/dd/DropTarget.java
index b2ab244c43..31c6754f6f 100644
--- a/src/com/vaadin/event/dd/DropTarget.java
+++ b/src/com/vaadin/event/dd/DropTarget.java
@@ -27,7 +27,7 @@ public interface DropTarget extends Component {
* {@link DropHandler}. Implementation may for exmaple translate the drop
* target details provided by the client side (drop target) to meaningful
* server side values. If null is returned the terminal implementation will
* automatically create a {@link DropTargetDetails} with raw client side
* data.
*
* @see DragSource#getTransferable(Map)
@@ -37,7 +37,7 @@ public interface DropTarget extends Component {
* @return A DropTargetDetails object with the translated data or null to
* use a default implementation.
*/
- public DropTargetDetails translateDropTargetDetails(
+ public TargetDetails translateDropTargetDetails(
Map<String, Object> clientVariables);
} \ No newline at end of file
@@ -27,7 +27,7 @@ public interface DropTarget extends Component {
* target details provided by the client side (drop target) to meaningful
* server side values. If null is returned the terminal implementation will
- * automatically create a {@link DropTargetDetails} with raw client side
+ * automatically create a {@link TargetDetails} with raw client side
* data.
*
diff --git a/src/com/vaadin/event/dd/DropTargetDetails.java b/src/com/vaadin/event/dd/TargetDetails.java
index 770d58d9d3..f83edf84d1 100644
--- a/src/com/vaadin/event/dd/DropTargetDetails.java
+++ b/src/com/vaadin/event/dd/TargetDetails.java
@@ -5,21 +5,21 @@ package com.vaadin.event.dd;
import java.io.Serializable;
-import com.vaadin.ui.Tree.TreeDropTargetDetails;
+import com.vaadin.ui.Tree.TreeTargetDetails;
/**
* DropTargetDetails wraps drop target related information about
* {@link DragAndDropEvent}.
* <p>
* When a DropTargetDetails object is used in {@link DropHandler} it is often
* preferable to cast the DropTargetDetail to an implementation provided by
* DropTarget like {@link TreeDropTargetDetails}. They often provide better
* typed, drop target specific API.
*
* @since 6.3
*
*/
-public interface DropTargetDetails extends Serializable {
+public interface TargetDetails extends Serializable {
/**
* Gets target data associated to given string key
@@ -5,21 +5,21 @@ package com.vaadin.event.dd;
/**
- * DropTargetDetails wraps drop target related information about
+ * TargetDetails wraps drop target related information about
* {@link DragAndDropEvent}.
* <p>
@@ -5,21 +5,21 @@ package com.vaadin.event.dd;
* {@link DragAndDropEvent}.
* <p>
- * When a DropTargetDetails object is used in {@link DropHandler} it is often
- * preferable to cast the DropTargetDetail to an implementation provided by
- * DropTarget like {@link TreeDropTargetDetails}. They often provide better
- * typed, drop target specific API.
+ * When a TargetDetails object is used in {@link DropHandler} it is often
+ * preferable to cast the TargetDetails to an implementation provided by
+ * DropTarget like {@link TreeTargetDetails}. They often provide a better typed,
+ * drop target specific API.
*
* @since 6.3
diff --git a/src/com/vaadin/event/dd/DropTargetDetailsImpl.java b/src/com/vaadin/event/dd/TargetDetailsImpl.java
index bcc35c623c..5b23a2a64f 100644
--- a/src/com/vaadin/event/dd/DropTargetDetailsImpl.java
+++ b/src/com/vaadin/event/dd/TargetDetailsImpl.java
@@ -7,23 +7,23 @@ import java.util.HashMap;
import java.util.Map;
/**
* A HashMap backed implementation of {@link DropTargetDetails} for terminal
* implementation and for extension.
*
* @since 6.3
*
*/
-public class DropTargetDetailsImpl implements DropTargetDetails {
+@SuppressWarnings("serial")
+public class TargetDetailsImpl implements TargetDetails {
- private static final long serialVersionUID = -5099462771593036776L;
private HashMap<String, Object> data = new HashMap<String, Object>();
private DropTarget dropTarget;
- protected DropTargetDetailsImpl(Map<String, Object> rawDropData) {
+ protected TargetDetailsImpl(Map<String, Object> rawDropData) {
data.putAll(rawDropData);
}
- public DropTargetDetailsImpl(Map<String, Object> rawDropData,
+ public TargetDetailsImpl(Map<String, Object> rawDropData,
DropTarget dropTarget) {
this(rawDropData);
this.dropTarget = dropTarget;
@@ -7,23 +7,23 @@ import java.util.HashMap;
import java.util.Map;
/**
- * A HashMap backed implementation of {@link DropTargetDetails} for terminal
+ * A HashMap backed implementation of {@link TargetDetails} for terminal
* implementation and for extension.
*
diff --git a/src/com/vaadin/event/dd/acceptcriteria/TargetDetailIs.java b/src/com/vaadin/event/dd/acceptcriteria/TargetDetailIs.java
index c20f10667d..89783aefe4 100644
--- a/src/com/vaadin/event/dd/acceptcriteria/TargetDetailIs.java
+++ b/src/com/vaadin/event/dd/acceptcriteria/TargetDetailIs.java
@@ -7,7 +7,7 @@
package com.vaadin.event.dd.acceptcriteria;
import com.vaadin.event.dd.DragAndDropEvent;
-import com.vaadin.event.dd.DropTargetDetails;
+import com.vaadin.event.dd.TargetDetails;
import com.vaadin.terminal.PaintException;
import com.vaadin.terminal.PaintTarget;
import com.vaadin.terminal.gwt.client.ui.dd.VTargetDetailIs;
@@ -30,7 +30,7 @@ public class TargetDetailIs extends ClientSideCriterion {
/**
* Constructs a criterion which ensures that the value there is a value in
* {@link DropTargetDetails} that equals the reference value.
*
* @param dataFlavor
* the type of data to be checked
@@ -30,7 +30,7 @@ public class TargetDetailIs extends ClientSideCriterion {
/**
* Constructs a criterion which ensures that the value there is a value in
- * {@link DropTargetDetails} that equals the reference value.
+ * {@link TargetDetails} that equals the reference value.
*
* @param dataFlavor